pub enum MetaLookupResult {
FamilyMiss,
RangeMiss,
QuickFilterMiss,
SstLookup(SstLookupResult),
}Expand description
The result of a lookup operation.
Variants
FamilyMiss
The key was not found because it is from a different key family.
RangeMiss
The key was not found because it is out of the range of this SST file. But it was the correct key family.
QuickFilterMiss
The key was not found because it was not in the AMQF filter. But it was in the range.
SstLookup(SstLookupResult)
The key was looked up in the SST file. It was in the AMQF filter.