MetaEntryFlags

Struct MetaEntryFlags 

pub struct MetaEntryFlags(pub u32);

Tuple Fields

0: u32

Implementations

Source

impl MetaEntryFlags

pub fn cold(&self) -> bool

The SST file was compacted and none of the entries have been accessed recently.

pub fn fresh(&self) -> bool

The SST file was freshly written and has not been compacted yet.

pub fn set_cold(&mut self, value: bool)

The SST file was compacted and none of the entries have been accessed recently.

pub fn set_fresh(&mut self, value: bool)

The SST file was freshly written and has not been compacted yet.

Source

impl MetaEntryFlags