pub fn advise_mmap_for_persistence(mmap: &Mmap) -> Result<()>Expand description
Apply Linux-specific mmap advice flags that should be set on all persistent mmaps.
DontFork: prevents mmap regions from being copied into child processes onfork(), avoiding unnecessary memory duplication and potential SIGBUS.