BlockCacheLifecycle

Struct BlockCacheLifecycle 

pub struct BlockCacheLifecycle;
Lifecycle hooks for the block cache that prevent eviction of entries still referenced outside the cache (i.e., with Arc strong count > 1).