MetaEntry

Struct MetaEntry 

pub struct MetaEntry { /* private fields */ }
Safety

MetaEntry stores a FilterRef<'static> with a transmuted lifetime that actually borrows from the parent MetaFile’s mmap. This is safe because entries are only accessed by reference through MetaFile and are never moved out.

For this reason this type should not implement Clone or Copy.

Implementations

Source

impl MetaEntry

pub fn sequence_number(&self) -> u32

pub fn size(&self) -> u64

pub fn flags(&self) -> MetaEntryFlags

pub fn amqf_size(&self) -> u32

pub fn raw_amqf<'l>(&self, amqf_data: &'l [u8]) -> &'l [u8]

Returns the raw serialized AMQF bytes from the mmap.

pub fn range(&self) -> StaticSortedFileRange

Returns the key family and hash range of this file.

pub fn min_hash(&self) -> u64

pub fn max_hash(&self) -> u64

pub fn block_count(&self) -> u16

pub fn sst_metadata(&self) -> StaticSortedFileMetaData

Returns the SST metadata needed to open the file independently. Used during compaction to avoid caching mmaps on the MetaEntry.