pub struct MetaEntry { /* private fields */ }Implementations
Sourceimpl MetaEntry
impl MetaEntry
pub fn sequence_number(&self) -> u32
pub fn size(&self) -> u64
pub fn flags(&self) -> MetaEntryFlags
pub fn amqf_size(&self) -> u32
pub fn raw_amqf<'l>(&self, amqf_data: &'l [u8]) -> &'l [u8] ⓘ
pub fn deserialize_amqf(&self, meta: &MetaFile) -> Result<Filter>
pub fn amqf(&self, meta: &MetaFile) -> Result<impl Deref<Target = Filter>>
pub fn sst(&self, meta: &MetaFile) -> Result<&StaticSortedFile>
Sourcepub fn range(&self) -> StaticSortedFileRange
pub fn range(&self) -> StaticSortedFileRange
Returns the key family and hash range of this file.
pub fn min_hash(&self) -> u64
pub fn max_hash(&self) -> u64
pub fn block_count(&self) -> u16
Sourcepub fn sst_metadata(&self) -> StaticSortedFileMetaData
pub fn sst_metadata(&self) -> StaticSortedFileMetaData
Returns the SST metadata needed to open the file independently. Used during compaction to avoid caching mmaps on the MetaEntry.