MetaFile

Struct MetaFile 

pub struct MetaFile { /* private fields */ }
Safety

entries must be declared before mmap so that Rust’s field drop order (declaration order) drops all FilterRefs before the mmap is unmapped. Reordering these fields would be unsound.

Implementations

Source

impl MetaFile

pub fn open(db_path: &Path, sequence_number: u32) -> Result<Self>

Opens a meta file at the given path. Memory maps the entire file and eagerly deserializes all AMQF filters as zero-copy [qfilter::FilterRef]s that borrow from the mmap.

pub fn clear_cache(&mut self)

pub fn prepare_sst_cache(&self)

pub fn sequence_number(&self) -> u32

pub fn family(&self) -> u32

pub fn entries(&self) -> &[MetaEntry]

pub fn entry(&self, index: u32) -> &MetaEntry

pub fn amqf_data(&self) -> &[u8]

pub fn deserialize_used_key_hashes_amqf(&self) -> Result<Option<FilterRef<'_>>>

pub fn retain_entries(&mut self, predicate: impl FnMut(u32) -> bool) -> bool

pub fn obsolete_entries(&self) -> &[u32]

pub fn has_active_entries(&self) -> bool

pub fn obsolete_sst_files(&self) -> &[u32]

pub fn lookup<K: QueryKey, const FIND_ALL: bool>( &self, key_family: u32, key_hash: u64, key: &K, key_block_cache: &BlockCache, value_block_cache: &BlockCache, ) -> Result<MetaLookupResult>

Looks up a key in this meta file.

If FIND_ALL is false, returns after finding the first match. If FIND_ALL is true, returns all entries with the same key from all SST files (useful for keyspaces where keys are hashes and collisions are possible).

pub fn batch_lookup<K: QueryKey>( &self, key_family: u32, keys: &[K], cells: &mut [(u64, usize, Option<LookupValue>)], empty_cells: &mut usize, key_block_cache: &BlockCache, value_block_cache: &BlockCache, ) -> Result<MetaBatchLookupResult>