SstFilter

Struct SstFilter 

pub struct SstFilter(/* private fields */);

Implementations

Source

impl SstFilter

pub fn new() -> Self

pub fn apply_filter(&mut self, meta: &mut MetaFile)

Phase 1: Apply the filter to the meta file and update the state in the filter.

pub fn apply_filter_collect(&mut self, meta: &MetaFile) -> FxHashSet<u32>

Like apply_filter but only updates the filter state without modifying the MetaFile. Returns the set of SST sequence numbers that should be removed from this meta file’s entries (they are superseded by a newer meta). Call meta.retain_entries(|seq| !obsolete.contains(&seq)) later to apply.

pub fn apply_and_get_remove(&mut self, meta: &MetaFile) -> bool

Phase 2: Check if the meta file can be removed based on the filter state after phase 1. Updates the filter state for the next meta file. Returns true if the meta file can be removed.