pub trait QueryKey: KeyBase {
// Required method
fn cmp(&self, key: &[u8]) -> Ordering;
}Expand description
A trait for keys that can be used to query the database. They need to allow hashing and comparison with a byte slice (total order).
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".